@@ -16,14 +16,13 @@ from django.views.decorators.csrf import csrf_exempt
 from . import version
 from .models import View
 from .orm import _OPEN_IN_ADMIN, get_models, get_results
-from .query import TYPES, BoundQuery, NumberFieldType, Query
+from .query import TYPES, BoundQuery, Query
 
 
 def _get_query_data(bound_query):
     return {
         "filters": [
             {
-                "errorMessage": filter_.err_message,
                 "path": filter_.path,
                 "prettyPath": filter_.pretty_path,
                 "lookup": filter_.lookup,
@@ -31,6 +30,7 @@ def _get_query_data(bound_query):
             }
             for filter_ in bound_query.filters
         ],
+        "filterErrors": [filter_.err_message for filter_ in bound_query.filters],
         "fields": [
             {
                 "path": field.path,
@@ -41,6 +41,7 @@ def _get_query_data(bound_query):
             for field in bound_query.fields
         ],
         "model": bound_query.model_name,
+        "version": version,
     }
 
 
@@ -50,31 +51,15 @@ def _get_model_fields(orm_model):
         front = {"id": 1, _OPEN_IN_ADMIN: 2}
         return sorted(fields, key=lambda x: front.get(x, sys.maxsize))
 
-    def type_model(orm_field):
-        if orm_field.concrete and orm_field.type_.aggregates:
-            return orm_field.type_.name
-        else:
-            return None
-
-    fields = {
+    all_fields = {
         name: {
-            "model": type_model(orm_field),
-            "type": orm_field.type_.name,
+            "model": orm_field.rel_name,
+            "type": orm_field.type_.name if orm_field.type_ else None,
             "concrete": orm_field.concrete,
             "prettyName": orm_field.pretty_name,
         }
         for name, orm_field in orm_model.fields.items()
     }
-    fk_fields = {
-        name: {
-            "model": fk_field.model_name,
-            "type": None,
-            "concrete": False,
-            "prettyName": fk_field.pretty_name,
-        }
-        for name, fk_field in orm_model.fks.items()
-    }
-    all_fields = {**fields, **fk_fields}
 
     return {"fields": all_fields, "sortedFields": sort_model_fields(all_fields)}
 
@@ -94,19 +79,6 @@ def _get_config(user, orm_models):
         model_name: _get_model_fields(orm_model)
         for model_name, orm_model in orm_models.items()
     }
-    for type_ in TYPES.values():
-        all_model_fields[type_.name] = {
-            "fields": {
-                aggregate: {
-                    "type": NumberFieldType.name,
-                    "concrete": True,
-                    "model": None,
-                    "prettyName": aggregate,
-                }
-                for aggregate in type_.aggregates
-            },
-            "sortedFields": type_.aggregates,
-        }
 
     saved_views = [
         {
@@ -128,7 +100,9 @@ def _get_config(user, orm_models):
         "adminUrl": admin_url,
         "types": types,
         "allModelFields": all_model_fields,
-        "sortedModels": sorted(orm_models),
+        "sortedModels": sorted(
+            name for name, model in orm_models.items() if model.root
+        ),
         "version": version,
         "savedViews": saved_views,
     }
@@ -197,7 +171,7 @@ def _data_response(request, query, media, meta):
     if media == "csv":
         buffer = io.StringIO()
         writer = csv.writer(buffer)
-        writer.writerow(f.path_str for f in bound_query.fields)
+        writer.writerow(" ".join(f.pretty_path) for f in bound_query.fields)
         writer.writerows(results)
         buffer.seek(0)
         response = http.HttpResponse(buffer, content_type="text/csv")
